@@ -21,6 +21,7 @@ class APIConstant:
     channelsURI = "/guilds/{guild_id}/channels"
     channelURI = "/channels/{channel_id}"
     channelPermissionsURI = "/channels/{channel_id}/members/{user_id}/permissions"
+    channelRolePermissionsURI = "/channels/{channel_id}/roles/{role_id}/permissions"
 
     messagesURI = "/channels/{channel_id}/messages"
     messageURI = "/channels/{channel_id}/messages/{message_id}"
@@ -35,6 +36,9 @@ class APIConstant:
     audioControlURI = "/channels/{channel_id}/audio"
     dmsURI = "/dms/{guild_id}/messages"
 
+    guildMuteURI = "/guilds/{guild_id}/mute"
+    guildMemberMuteURI = "/guilds/{guild_id}/members/{user_id}/mute"
+
 
 def get_url(url_format, is_sandbox):
     d = BaseConstant.domain
